@@ -14,7 +14,7 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
 /**
- * Constains the dictionary of language entries.
+ * Contains the dictionary of language entries.
  * @namespace
  */
 CKEDITOR.lang['is'] =
@@ -121,6 +121,10 @@ CKEDITOR.lang['is'] =
 		alignBottom		: 'Neðst',
 		invalidHeight	: 'Height must be a number.', // MISSING
 		invalidWidth	: 'Width must be a number.', // MISSING
+		invalidCssLength	: 'Value specified for the "%1" field must be a positive number with or without a valid CSS measurement unit (px, %, in, cm, mm, em, ex, pt, or pc).', // MISSING
+		invalidHtmlLength	: 'Value specified for the "%1" field must be a positive number with or without a valid HTML measurement unit (px or %).', // MISSING
+		invalidInlineStyle	: 'Value specified for the inline style must consist of one or more tuples with the format of "name : value", separated by semi-colons.', // MISSING
+		cssLengthTooltip	: 'Enter a number for a value in pixels or a number with a valid CSS unit (px, %, in, cm, mm, em, ex, pt, or pc).', // MISSING
 
 		// Put the voice-only part of the label in the span.
 		unavailable		: '%1<span class="cke_accessibility">, unavailable</span>' // MISSING
@@ -201,7 +205,8 @@ CKEDITOR.lang['is'] =
 		menu		: 'Eigindi kaflamerkis',
 		title		: 'Eigindi kaflamerkis',
 		name		: 'Nafn bókamerkis',
-		errorName	: 'Sláðu inn nafn bókamerkis!'
+		errorName	: 'Sláðu inn nafn bókamerkis!',
+		remove		: 'Remove Anchor' // MISSING
 	},
 
 	// List style dialog
@@ -237,6 +242,7 @@ CKEDITOR.lang['is'] =
 		findWhat			: 'Leita að:',
 		replaceWith			: 'Skipta út fyrir:',
 		notFoundMsg			: 'Leitartexti fannst ekki!',
+		findOptions			: 'Find Options', // MISSING
 		matchCase			: 'Gera greinarmun á¡ há¡- og lágstöfum',
 		matchWord			: 'Aðeins heil orð',
 		matchCyclic			: 'Match cyclic', // MISSING
@@ -271,8 +277,8 @@ CKEDITOR.lang['is'] =
 		invalidBorder	: 'Border size must be a number.', // MISSING
 		invalidWidth	: 'Table width must be a number.', // MISSING
 		invalidHeight	: 'Table height must be a number.', // MISSING
-		invalidCellSpacing	: 'Cell spacing must be a number.', // MISSING
-		invalidCellPadding	: 'Cell padding must be a number.', // MISSING
+		invalidCellSpacing	: 'Cell spacing must be a positive number.', // MISSING
+		invalidCellPadding	: 'Cell padding must be a positive number.', // MISSING
 
 		cell :
 		{
@@ -413,7 +419,6 @@ CKEDITOR.lang['is'] =
 		upload		: 'Hlaða upp',
 		alt			: 'Baklægur texti',
 		lockRatio	: 'Festa stærðarhlutfall',
-		unlockRatio	: 'Unlock Ratio', // MISSING
 		resetSize	: 'Reikna stærð',
 		border		: 'Rammi',
 		hSpace		: 'Vinstri bil',
@@ -770,41 +775,41 @@ CKEDITOR.lang['is'] =
 
 	docprops :
 	{
-		label : 'Document Properties', // MISSING
-		title : 'Document Properties', // MISSING
+		label : 'Eigindi skjals',
+		title : 'Eigindi skjals',
 		design : 'Design', // MISSING
-		meta : 'Meta Tags', // MISSING
+		meta : 'Lýsigögn',
 		chooseColor : 'Choose', // MISSING
-		other : 'Other...', // MISSING
-		docTitle :	'Page Title', // MISSING
-		charset : 	'Character Set Encoding', // MISSING
-		charsetOther : 'Other Character Set Encoding', // MISSING
+		other : '<annar>',
+		docTitle :	'Titill síðu',
+		charset : 	'Letursett',
+		charsetOther : 'Annað letursett',
 		charsetASCII : 'ASCII', // MISSING
-		charsetCE : 'Central European', // MISSING
-		charsetCT : 'Chinese Traditional (Big5)', // MISSING
-		charsetCR : 'Cyrillic', // MISSING
-		charsetGR : 'Greek', // MISSING
-		charsetJP : 'Japanese', // MISSING
-		charsetKR : 'Korean', // MISSING
-		charsetTR : 'Turkish', // MISSING
+		charsetCE : 'Mið-evrópskt',
+		charsetCT : 'Kínverskt, hefðbundið (Big5)',
+		charsetCR : 'Kýrilskt',
+		charsetGR : 'Grískt',
+		charsetJP : 'Japanskt',
+		charsetKR : 'Kóreskt',
+		charsetTR : 'Tyrkneskt',
 		charsetUN : 'Unicode (UTF-8)', // MISSING
-		charsetWE : 'Western European', // MISSING
-		docType : 'Document Type Heading', // MISSING
-		docTypeOther : 'Other Document Type Heading', // MISSING
-		xhtmlDec : 'Include XHTML Declarations', // MISSING
-		bgColor : 'Background Color', // MISSING
-		bgImage : 'Background Image URL', // MISSING
-		bgFixed : 'Non-scrolling (Fixed) Background', // MISSING
-		txtColor : 'Text Color', // MISSING
-		margin : 'Page Margins', // MISSING
-		marginTop : 'Top', // MISSING
-		marginLeft : 'Left', // MISSING
-		marginRight : 'Right', // MISSING
-		marginBottom : 'Bottom', // MISSING
-		metaKeywords : 'Document Indexing Keywords (comma separated)', // MISSING
-		metaDescription : 'Document Description', // MISSING
-		metaAuthor : 'Author', // MISSING
-		metaCopyright : 'Copyright', // MISSING
+		charsetWE : 'Vestur-evrópst',
+		docType : 'Flokkur skjalategunda',
+		docTypeOther : 'Annar flokkur skjalategunda',
+		xhtmlDec : 'Fella inn XHTML lýsingu',
+		bgColor : 'Bakgrunnslitur',
+		bgImage : 'Slóð bakgrunnsmyndar',
+		bgFixed : 'Læstur bakgrunnur',
+		txtColor : 'Litur texta',
+		margin : 'Hliðarspássía',
+		marginTop : 'Efst',
+		marginLeft : 'Vinstri',
+		marginRight : 'Hægri',
+		marginBottom : 'Neðst',
+		metaKeywords : 'Lykilorð efnisorðaskrár (aðgreind með kommum)',
+		metaDescription : 'Lýsing skjals',
+		metaAuthor : 'Höfundur',
+		metaCopyright : 'Höfundarréttur',
 		previewHtml : '<p>This is some <strong>sample text</strong>. You are using <a href="javascript:void(0)">CKEditor</a>.</p>' // MISSING
 	}
 };
