@@ -3,7 +3,6 @@ Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 Drupal.ckeditor = (typeof(CKEDITOR) != 'undefined');
-
 // this object will store teaser information
 Drupal.ckeditorTeaser = {
   lookup: {},
@@ -41,8 +40,8 @@ Drupal.ckeditorOn = function(textarea_id) {
   if (!CKEDITOR.env.isCompatible) {
     return;
   }
-
-  if (teaser = Drupal.ckeditorTeaserInfo(textarea_id)) {
+  var teaser = Drupal.ckeditorTeaserInfo(textarea_id);
+  if (teaser) {
     var ch_checked = teaser.checkbox.attr('checked');
     var tv = teaser.textarea.val();
     if (!teaser.textarea.attr("disabled")) {
@@ -54,7 +53,7 @@ Drupal.ckeditorOn = function(textarea_id) {
     if (teaser.button.attr('value') != Drupal.t('Split summary at cursor')) {
       try {
         teaser.button.click();
-      } 
+      }
       catch (e) {
         teaser.button.val(Drupal.t('Split summary at cursor'));
       }
@@ -66,7 +65,7 @@ Drupal.ckeditorOn = function(textarea_id) {
     teaser.checkbox.attr('checked', ch_checked);
   }
 
-  if (($("#" + textarea_id).val().length > 0) && ($("#" + textarea_id).attr('class').indexOf("filterxss1") != -1 || $("#" + textarea_id).attr('class').indexOf("filterxss2") != -1)) {
+  if (( $("#" + textarea_id) .length > 0 && $("#" + textarea_id).val().length > 0) && ($("#" + textarea_id).attr('class').indexOf("filterxss1") != -1 || $("#" + textarea_id).attr('class').indexOf("filterxss2") != -1)) {
     $.post(Drupal.settings.basePath + 'index.php?q=ckeditor/xss', {
       text: $('#' + textarea_id).val(),
       'filters[]': Drupal.settings.ckeditor.settings[textarea_id].filters
@@ -78,7 +77,10 @@ Drupal.ckeditorOn = function(textarea_id) {
   $("#" + textarea_id).next(".grippie").css("display", "none");
   $("#" + textarea_id).addClass("ckeditor-processed");
 
-  Drupal.settings.ckeditor.settings[textarea_id]['on'] = 
+  var textarea_settings = false;
+  Drupal.settings.ckeditor.settings[textarea_id].toolbar = eval(Drupal.settings.ckeditor.settings[textarea_id].toolbar);
+  textarea_settings = Drupal.settings.ckeditor.settings[textarea_id];
+  textarea_settings['on'] =
   {
     configLoaded  : function(ev)
     {
@@ -87,14 +89,18 @@ Drupal.ckeditorOn = function(textarea_id) {
     instanceReady : function(ev)
     {
       var body = $(ev.editor.document.$.body);
-      if (typeof(Drupal.settings.ckeditor.settings[textarea_id].custom_formatting) != 'undefined') {
+      // Don't enter line breaks after paragraph so we can be friendly to drupal's line break filter.
+      ev.editor.dataProcessor.writer.setRules('p', {
+        breakAfterOpen: false
+      });
+      if (typeof(textarea_settings.custom_formatting) != 'undefined') {
         var dtd = CKEDITOR.dtd;
         for ( var e in CKEDITOR.tools.extend( {}, dtd.$block, dtd.$listItem, dtd.$tableContent ) ) {
-          ev.editor.dataProcessor.writer.setRules( e, Drupal.settings.ckeditor.settings[textarea_id].custom_formatting);
-		}
+          ev.editor.dataProcessor.writer.setRules( e, textarea_settings.custom_formatting);
+    }
         ev.editor.dataProcessor.writer.setRules( 'pre',
         {
-          indent: Drupal.settings.ckeditor.settings[textarea_id].output_pre_indent
+          indent: textarea_settings.output_pre_indent
         });
       }
 
@@ -112,7 +118,21 @@ Drupal.ckeditorOn = function(textarea_id) {
     }
   };
 
-  Drupal.ckeditorInstance = CKEDITOR.replace(textarea_id, Drupal.settings.ckeditor.settings[textarea_id]);
+  if (typeof textarea_settings['js_conf'] != 'undefined'){
+      for (var add_conf in textarea_settings['js_conf']){
+          textarea_settings[add_conf] = eval(textarea_settings['js_conf'][add_conf]);
+      }
+  }
+
+  textarea_settings.extraPlugins = '';
+  if (typeof CKEDITOR.plugins != 'undefined'){
+    for (var plugin in textarea_settings['loadPlugins']){
+      textarea_settings.extraPlugins += (textarea_settings.extraPlugins) ? ',' + textarea_settings['loadPlugins'][plugin]['name'] : textarea_settings['loadPlugins'][plugin]['name'];
+      CKEDITOR.plugins.addExternal(textarea_settings['loadPlugins'][plugin]['name'], textarea_settings['loadPlugins'][plugin]['path']);
+    }
+  }
+
+  Drupal.ckeditorInstance = CKEDITOR.replace(textarea_id, textarea_settings);
 };
 
 /**
@@ -132,7 +152,8 @@ Drupal.ckeditorOff = function(textarea_id) {
 
   var data = CKEDITOR.instances[textarea_id].getData();
   CKEDITOR.instances[textarea_id].destroy();
-  if (teaser = Drupal.ckeditorTeaserInfo(textarea_id)) {
+  var teaser = Drupal.ckeditorTeaserInfo(textarea_id);
+  if (teaser) {
     var brcode = /<!--break-->/;
     data = data.split(brcode);
     if (data.length > 1) {
@@ -141,7 +162,7 @@ Drupal.ckeditorOff = function(textarea_id) {
       if (teaser.button.attr('value') != Drupal.t('Join summary')) {
         try {
           teaser.button.click();
-        } 
+        }
         catch (e) {
           teaser.button.val(Drupal.t('Join summary'));
         }
@@ -156,7 +177,7 @@ Drupal.ckeditorOff = function(textarea_id) {
       if (teaser.button.attr('value') != Drupal.t('Split summary at cursor')) {
         try {
           teaser.button.click();
-        } 
+        }
         catch (e) {
           teaser.button.val(Drupal.t('Split summary at cursor'));
         }
@@ -174,7 +195,6 @@ Drupal.ckeditorOff = function(textarea_id) {
  */
 function ckeditorOpenPopup(jsID, textareaID, width){
   popupUrl = Drupal.settings.ckeditor.module_path + '/includes/ckeditor.popup.html?var=' + jsID + '&el=' + textareaID;
-  
   var percentPos = width.indexOf('%');
   if (percentPos != -1) {
     width = width.substr(0, percentPos);
@@ -217,7 +237,6 @@ Drupal.ckeditorTeaserInfo = function(taid) {
   if (Drupal.ckeditorTeaser.cache[taid]) {
     return Drupal.ckeditorTeaser.cache[taid];
   }
-  
   // build a lookup table
   if (!Drupal.ckeditorTeaser.lookupSetup) {
     Drupal.ckeditorTeaser.lookupSetup = true;
@@ -225,7 +244,6 @@ Drupal.ckeditorTeaserInfo = function(taid) {
       Drupal.ckeditorTeaser.lookup[Drupal.settings.teaser[x]] = x;
     }
   }
-  
   // find the elements
   if (Drupal.ckeditorTeaser.lookup[taid]) {
     var obj;
@@ -240,19 +258,16 @@ Drupal.ckeditorTeaserInfo = function(taid) {
         checkbox: $('#' + Drupal.settings.teaserCheckbox[Drupal.ckeditorTeaser.lookup[taid]])
       };
     }
-    
     obj.textareaContainer = obj.textarea.parent();
     obj.checkboxContainer = obj.checkbox.parent();
-    
     obj.button = $('input.teaser-button', obj.checkbox.parents('div.teaser-checkbox').get(0));
     obj.buttonContainer = obj.button.parent();
-    
     Drupal.ckeditorTeaser.cache[taid] = obj;
   }
   else {
     Drupal.ckeditorTeaser.cache[taid] = null;
   }
-  
+
   return Drupal.ckeditorTeaser.cache[taid];
 };
 
@@ -265,7 +280,7 @@ Drupal.ckeditorInsertHtml = function(html) {
     return true;
   }
   else {
-    alert(Drupal.t('Content can be only inserted into CKEditor in WYSIWYG mode.'));
+    alert(Drupal.t('Content can only be inserted into CKEditor in the WYSIWYG mode.'));
     return false;
   }
 };
@@ -332,10 +347,21 @@ Drupal.ckeditorSubmitAjaxForm = function () {
 /**
  * Drupal behaviors
  */
+var imagefield_data = new Object();
 Drupal.behaviors.ckeditor = function (context) {
   if ((typeof(CKEDITOR) == 'undefined') || !CKEDITOR.env.isCompatible) {
     return;
   }
+
+  if (typeof CKEDITOR.instances != 'undefined')
+  {
+      $.each(CKEDITOR.instances, function(index, value){
+        if ($('#'+index).length == 0)
+        {
+          delete CKEDITOR.instances[index];
+        }
+      });
+  }
   $('.ckeditor_links').show();
   // make sure the textarea behavior is run first, to get a correctly sized grippie
   // the textarea behavior requires the teaser behavior, so load that one as well
@@ -346,6 +372,74 @@ Drupal.behaviors.ckeditor = function (context) {
     Drupal.behaviors.textarea(context);
   }
 
+  //Support for imageField [#1286192]
+  if (Drupal.behaviors.filefieldButtons) {
+    $('input[id$="-add-more"]:submit').each(function(){
+      $(this).mousedown(function(){
+        $('.form-item textarea.ckeditor-mod', $(this).parent().prev().html()).each(function(){
+          if (typeof CKEDITOR.instances[$(this).attr('id')] != 'undefined') {
+            imagefield_data[$(this).attr('id')] = CKEDITOR.instances[$(this).attr('id')].getData();
+          }
+          Drupal.ckeditorOff($(this).attr('id'));
+        });
+      });
+    });
+    if ($('.form-item textarea', $(context)).length == 1) {
+      var url = document.location.pathname;
+      if (url.indexOf('/') == 0 ) url =  url.substr(1);
+      var path = Drupal.settings.basePath;
+      var imagefield_id = $('textarea', $(context)).attr('id');
+      if (!CKEDITOR.instances[imagefield_id]){
+        $.ajax({
+          url: path + 'admin/ckeditor/get_settings',
+          dataType: 'json',
+          data: {'id': imagefield_id, 'url': url},
+          type: 'POST',
+          success: function( data ) {
+            Drupal.settings.ckeditor.settings[imagefield_id] = data;
+            if ($(data).length > 0) {
+              Drupal.settings.ckeditor.autostart[imagefield_id] = true;
+              Drupal.ckeditorOn(imagefield_id);
+            }
+          }
+        });
+        $('input[id$="-filefield-remove"]', $(context)).mousedown(function(){
+          $('textarea.ckeditor-mod', $(context)).each(function(){
+            if (CKEDITOR.instances[$(this).attr('id')]){
+              Drupal.ckeditorOff($(this).attr('id'));
+              imagefield_data[$(this).attr('id')] = "";
+            }
+          })
+        });
+      }
+    }
+  }
+
+  //Added for support [#1288664] Views
+  if ($(context).attr('id') === 'views-ajax-pad'){
+    $("div.form-buttons input#edit-submit").click(function(){
+        if (typeof CKEDITOR.instances['edit-header'] != 'undefined' )$('#edit-header').attr('value',CKEDITOR.instances['edit-header'].document.getBody().getHtml());
+        if (typeof CKEDITOR.instances['edit-footer'] != 'undefined' )$('#edit-footer').attr('value',CKEDITOR.instances['edit-footer'].document.getBody().getHtml());
+        if (typeof CKEDITOR.instances['edit-empty'] != 'undefined' )$('#edit-empty').attr('value',CKEDITOR.instances['edit-empty'].document.getBody().getHtml());
+    });
+    var views_textarea_id = $("textarea", $(context)).attr('id');
+    if (typeof views_textarea_id != 'undefined' && views_textarea_id != 'edit-options-alter-text'){
+      path = Drupal.settings.basePath;
+      $.ajax({
+        url: path + 'admin/ckeditor/get_settings',
+        dataType: 'json',
+        data: {'id': views_textarea_id, 'url': 'admin/build/views'},
+        type: 'POST',
+        success: function( data ) {
+          if ($(data).length > 0 && typeof CKEDITOR.instances[views_textarea_id] == 'undefined'){
+            Drupal.settings.ckeditor.settings[views_textarea_id] = data;
+            Drupal.ckeditorOn(views_textarea_id);
+          }
+        }
+      });
+    }
+  }
+
   // Support for Panels [#679976]
   if ($(context).attr('id') == 'modal-content') {
     if (CKEDITOR.instances['edit-body'] != 'undefined') {
@@ -363,19 +457,45 @@ Drupal.behaviors.ckeditor = function (context) {
         $('body').unbind('keypress');
       };
     });
-  }  
+  }
 
   $("textarea.ckeditor-mod:not(.ckeditor-processed)").each(function () {
     var ta_id=$(this).attr("id");
-    if ((typeof(Drupal.settings.ckeditor.autostart) != 'undefined') && (typeof(Drupal.settings.ckeditor.autostart[ta_id]) != 'undefined')) {
+    if ((typeof(Drupal.settings.ckeditor.autostart) != 'undefined') && (typeof(Drupal.settings.ckeditor.autostart[ta_id]) != 'undefined') ) {
+      if(typeof imagefield_data[ta_id] == "string") {
+        $("#"+ta_id).attr('value', imagefield_data[ta_id]);
+      }
       Drupal.ckeditorOn(ta_id);
     }
-    else {
-      $(this).parents('form').bind('submit', function() {
-        $(this).find('textarea').each(function() {
-          $(this).val(Drupal.ckeditorLinebreakConvert(ta_id, $(this).val()));
-        });
-      });
-    }
   });
-};
\ No newline at end of file
+
+  $("form").bind('submit', function() {
+    $(this).find('textarea.ckeditor-processed').each(function() {
+      $(this).val(Drupal.ckeditorLinebreakConvert($(this).attr("id"), $(this).val()));
+    });
+  });
+};
+
+if (Drupal.tableDrag) {
+    Drupal.tableDrag.prototype.onDrag = function() {
+      $(this.rowObject.element).find('textarea.ckeditor-processed').each(
+        function() {
+          if (typeof(CKEDITOR.instances) != 'undefined' && typeof(CKEDITOR.instances[$(this).attr('id')]) != 'undefined') {
+            data = CKEDITOR.instances[$(this).attr('id')].document.getBody().getHtml();
+            $("#"+$(this).attr('id')).attr('value',data);
+            Drupal.ckeditorOff($(this).attr('id'));
+          }
+        }
+      );
+    };
+    Drupal.tableDrag.prototype.onDrop = function() {
+
+      $(this.rowObject.element).find('textarea.ckeditor-mod:not(.ckeditor-processed)').each(
+        function() {
+          if ((typeof(Drupal.settings.ckeditor.autostart) != 'undefined') && (typeof(Drupal.settings.ckeditor.autostart[$(this).attr('id')]) != 'undefined')) {
+            Drupal.ckeditorOn($(this).attr('id'));
+          }
+        }
+      );
+    };
+}
\ No newline at end of file
